@@ -3,12 +3,16 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from asana.api.access_requests_api import AccessRequestsApi
+from asana.api.allocations_api import AllocationsApi
 from asana.api.attachments_api import AttachmentsApi
 from asana.api.audit_log_api_api import AuditLogAPIApi
 from asana.api.batch_api_api import BatchAPIApi
 from asana.api.custom_field_settings_api import CustomFieldSettingsApi
 from asana.api.custom_fields_api import CustomFieldsApi
+from asana.api.custom_types_api import CustomTypesApi
 from asana.api.events_api import EventsApi
+from asana.api.exports_api import ExportsApi
 from asana.api.goal_relationships_api import GoalRelationshipsApi
 from asana.api.goals_api import GoalsApi
 from asana.api.jobs_api import JobsApi
@@ -21,6 +25,7 @@ from asana.api.project_memberships_api import ProjectMembershipsApi
 from asana.api.project_statuses_api import ProjectStatusesApi
 from asana.api.project_templates_api import ProjectTemplatesApi
 from asana.api.projects_api import ProjectsApi
+from asana.api.reactions_api import ReactionsApi
 from asana.api.rules_api import RulesApi
 from asana.api.sections_api import SectionsApi
 from asana.api.status_updates_api import StatusUpdatesApi
